# pyxq
[![pypi](https://img.shields.io/pypi/v/pyxq.svg)](https://pypi.python.org/pypi/pyxq)
[![travis-ci](https://www.travis-ci.com/goodchinas/pyxq.svg?branch=master)](https://travis-ci.com/goodchinas/pyxq)
[![readthedocs](https://readthedocs.org/projects/pyxq/badge/?version=latest)](https://pyxq.readthedocs.io/en/latest/?badge=latest)
<a href="https://pyup.io/repos/github/goodchinas/pyxq/"><img alt="pyup" src="https://pyup.io/repos/github/goodchinas/pyxq/shield.svg"></a>

python quant is so easy.

* Free software: MIT license
* Documentation: https://pyxq.readthedocs.io.


# Features
* TODO

# Credits
This package was created with [Cookiecutter](https://github.com/audreyr/cookiecutter) and the [audreyr/cookiecutter-pypackage](https://github.com/audreyr/cookiecutter-pypackage) project template.


